#!/usr/bin/env bash

source ./functions.sh
source ./hosts.sh

# ADJUSTABLE PARAMETERS
# set directory containing jobs to be run
jobs=( "../4-jobs/18_04_02/5w81-swiss*/" )
step_size=1000000
#repeats=50


# FUNCTIONS
# remove trailing slashes from jobs array
jobs=(${jobs[@]%/})


# HOSTNAME PARAMETERS
function run_namd() {
  case "${HOSTNAME}" in
    "phy145.physiology.uab.edu") # Workstation (local)
      namd_param='/home/bryan/bin/namd/namd2 +p55 +idlepoll'
      run_workstation
      ;;
    "login001") # Cheaha (Slurm)
      namd_param='charmrun ++mpiexec ++nodelist ${TMPDIR}/nodelist.${SLURM_JOBID} +p ${SLURM_NTASKS} ${namd_bin}'
      partition="short"
      ntasks=96
      nodes=4
      time="12:00:00"
      mem_per_cpu=128
      run_cheaha
      ;;
    "uv.asc.edu") # ASC (Slurm script)
      namd_param="runnamd"
      queue_name_pref="large"
      num_cpus_pref=64
      cpu_time_pref="DEFAULT"
      memory_pref="16gb"
      cluster_pref='"uv|dmc"'
      run_asc
      ;;
     *) # unknown
       echo "You are running on an unknown system: \"${HOSTNAME}\"..."
       echo "You must first add this machine to the resources section in run_namd.sh"
       echo "Exiting..."
       exit 1
       ;;
  esac
}


# RUN LOOP

for r in {1..50}; do
  for job in "${jobs[@]}"; do
    get_next_step
    copy_ffs
    create_conf
    backup
    run_namd
  done
done
